package Netstack;
use strict;
use warnings;

=encoding utf8

=head1 NAME

Netstack - Network automation development toolkit

=head1 SYNOPSIS

  # Netstack::Connector::Role
    该项目使用 Moose 编写相关代码逻辑，当前支持的功能如下：
    1、支持定义enable模式；
    2、支持初阶的错误代码拦截；
    3、支持用户自定义自动交互运行代码；
    4、支持 interact 模式；
    5、支持灵活扩展多厂商及不同厂商下的任务编排：抓取运行环境、配置


=head1 DESCRIPTION
    待完善功能描述和模块使用概要

=head1 SEE ALSO

L<Netstack>, L<https://github.com/snmpd/netstack>.

=cut

# ABSTRACT: turns baubles into trinkets
1;
